FlexibleScrollbar class

Inheritance

Constructors

FlexibleScrollbar({Key? key, required Widget child, required ScrollController controller, ScrollWidgetBuilder? scrollThumbBuilder, ScrollWidgetBuilder? scrollLineBuilder, ScrollWidgetBuilder? scrollLabelBuilder, double? scrollLineOffset, ValueChanged<DragStartDetails>? onDragStart, ValueChanged<DragEndDetails>? onDragEnd, ValueChanged<DragUpdateDetails>? onDragUpdate, double? thumbMainAxisMinSize, Duration? thumbFadeStartDuration, Duration? thumbFadeDuration, double? scrollLineCrossAxisSize, BarPosition barPosition = BarPosition.end, bool alwaysVisible = false, bool jumpOnScrollLineTapped = true, bool draggable = true, bool autoPositionLabel = true, double scrollLabelOffset = 4})

Properties

alwaysVisible bool
Default value is false. If true prevents the scroll thumb from disappearing after the set time
final
autoPositionLabel bool
Default value is true. If false the label is set to (0, 0) position and can be moved using Positioned widget
final
barPosition BarPosition
Defines whether the scroll line position at the start or the end of the scroll body cross axis
final
child Widget
final
controller ScrollController
The scroll controller of the scrollable widget
final
draggable bool
Default value is true. If false prevents user from dragging the scroll thumb
final
hashCode int
The hash code for this object.
no setterinherited
jumpOnScrollLineTapped bool
Default value is true. If false prevents the scroll position change on the scroll line tap
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDragEnd ValueChanged<DragEndDetails>?
This callback is called when the user ends dragging the scroll thumb
final
onDragStart ValueChanged<DragStartDetails>?
This callback is called when the user starts dragging the scroll thumb
final
onDragUpdate ValueChanged<DragUpdateDetails>?
This callback is called during the user's scroll thumb drag process
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollLabelBuilder ScrollWidgetBuilder?
final
scrollLabelOffset double
The offset in pixels of the label from the side defined by the barPosition and the scroll direction
final
scrollLineBuilder ScrollWidgetBuilder?
final
scrollLineCrossAxisSize double?
The cross axis size of the scroll line. Defaults to the scroll thumb size. The scroll thumb cross axis size can not be bigger then this field
final
scrollLineOffset double?
The offset in pixels of the scroll line from the side defined by the barPosition and the scroll direction
final
scrollThumbBuilder ScrollWidgetBuilder?
final
thumbFadeDuration Duration?
The time that takes the scroll thumb to completely fade
final
thumbFadeStartDuration Duration?
Defines the time after which the scroll thumb will start its fade animation
final
thumbMainAxisMinSize double?
The minimal size of the scroll thumb in case you are using the ScrollbarInfo thumbMainAxisSize and the scroll body is too big
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _FlexibleScrollbarState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited