onDragStart property
This callback is called when the user starts dragging the scroll thumb
Implementation
final ValueChanged<DragStartDetails>? onDragStart;
This callback is called when the user starts dragging the scroll thumb
final ValueChanged<DragStartDetails>? onDragStart;